From f73b655466092169abac34833fb628fce1fcdebe Mon Sep 17 00:00:00 2001
From: jcduff <jcduff@localhost>
Date: Thu, 23 Oct 2008 14:04:24 +0000
Subject: [PATCH] The commit will bring the following features :     - An updated version of the underlying database. BDB JE 3.3 is now used.     - Attribute API refactoring providing a better abstraction and offering improved performances.     - A new GUI called the Control-Panel to replace the Status-Panel: the specifications for this       GUI are available on OpenDS Wiki and contains a link to a mockup.        See <https://www.opends.org/wiki/page/ControlPanelUISpecification>.     - Some changes in the replication protocol to implement "Assured Replication Mode". The        specifications are on OpenDS Wiki at <https://www.opends.org/wiki/page/AssuredMode> and section 7       described some of the replication changes required to support this. Assured Replication is not finished,       but the main replication protocol changes to support it are done. As explained by Gilles on an email on       the Dev mailing list (http://markmail.org/message/46rgo3meq3vriy4a), with these changes the newer versions       of OpenDS may not be able to replicate with OpenDS 1.0 instances.     - Support for Service Tags on the platforms where the functionality is available and enabled. Specifications       are published at <https://www.opends.org/wiki/page/OpenDSServiceTagEnabled>. For more information on       Service Tags see <http://wikis.sun.com/display/ServiceTag/Sun+Service+Tag+FAQ>.     - The Admin Connector service. In order to provide agentry of the OpenDS server at any time, a new service       has been added, dedicated to the administration, configuration and monitoring of the server.       An overview of the Admin Connector service and it's use is available on the       OpenDS wiki <https://www.opends.org/wiki/page/ManagingAdministrationTrafficToTheServer>     - Updates to the various command line tools to support the Admin Connector service.     - Some internal re-architecting of the server to put the foundation of future developments such as virtual       directory services. The new NetworkGroups and WorkFlow internal services which have been specified in       <https://www.opends.org/wiki/page/BasicOperationRoutingThroughNetworkGroup> are now implemented.     - Many bug fixes...

---
 opends/src/server/org/opends/server/replication/plugin/FakeOperation.java |   24 ++++++------------------
 1 files changed, 6 insertions(+), 18 deletions(-)

diff --git a/opends/src/server/org/opends/server/replication/plugin/FakeOperation.java b/opends/src/server/org/opends/server/replication/plugin/FakeOperation.java
index a67621f..3b2f4ff 100644
--- a/opends/src/server/org/opends/server/replication/plugin/FakeOperation.java
+++ b/opends/src/server/org/opends/server/replication/plugin/FakeOperation.java
@@ -27,18 +27,16 @@
 package org.opends.server.replication.plugin;
 
 import org.opends.server.replication.common.ChangeNumber;
-import org.opends.server.replication.protocol.ReplicationMessage;
-import org.opends.server.types.Modification;
+import org.opends.server.replication.protocol.ReplicationMsg;
 
 
 /**
  * This class if used to build fake Operation from the historical
  * information that stay in the entry in the database.
  *
- * This is usefull when a LDAP server can't find a LDAP server that
+ * This is useful when a LDAP server can't find a LDAP server that
  * has already seen all its changes and therefore need to retransmit them
  *
- * @author Gilles Bellaton
  */
 public abstract class FakeOperation
 {
@@ -65,22 +63,12 @@
   }
 
   /**
    * Generate a ReplicationMessage from this fake operation.
    * The ReplicationMessage is used to send the informations about
    * this operation to the other servers.
    *
    * @return A ReplicationMessage that can be used to send information
    *         about this operation to remote servers.
    */
-  abstract public ReplicationMessage generateMessage();
-
-  /**
-   * Add a modification to the list of modification included
-   * in this fake operation.
-   *
-   * @param mod A modification that must be adde to the list of modifications
-   *            included in this fake operation.
-   */
-  abstract public void addModification(Modification mod);
-
+  abstract public ReplicationMsg generateMessage();
 }
@@ -65,22 +63,12 @@
 
   /**
-   * Generate a ReplicationMessage from this fake operation.
-   * The ReplicationMessage is used to send the informations about
+   * Generate a ReplicationMsg from this fake operation.
+   * The ReplicationMsg is used to send the informations about
    * this operation to the other servers.
    *
@@ -65,22 +63,12 @@
    * this operation to the other servers.
    *
-   * @return A ReplicationMessage that can be used to send information
+   * @return A ReplicationMsg that can be used to send information
    *         about this operation to remote servers.
    */

--
Gitblit v1.10.0